Changelog
---------

0.3.1 (2016-08-20)
~~~~~~~~~~~~~~~~~~
- Added export command
- Added version command
- Added -t option for dependency type filtering
- Fixed bug in Apt.pkgs population

0.3 (2016-08-19)
~~~~~~~~~~~~~~~~~~
- Added apt version support
- Added full version relation support

0.2.1 (2016-08-16)
~~~~~~~~~~~~~~~~~~
- Refactored command() for functionality and security

0.2 (2016-08-05)
~~~~~~~~~~~~~~~~
- Added dependency satisfaction optimizations

0.1 (2016-08-03)
~~~~~~~~~~~~~~~~
Initial release.
